========
EpiStoch
========


.. image:: https://img.shields.io/pypi/v/epistoch.svg
        :target: https://pypi.python.org/pypi/epistoch

.. image:: https://img.shields.io/travis/griano/epistoch.svg
        :target: https://travis-ci.com/griano/epistoch

.. image:: https://readthedocs.org/projects/epistoch/badge/?version=latest
        :target: https://epistoch.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Epidemics Models with Random Infectious Period
----------------------------------------------

This software allows you to model epidemics with general random distribution for the infectious period.



* The theoretical foundation of the method is explained in this paper_
* Source: https://github.com/griano/epistoch
* Free software: MIT license. THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
  EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.




.. _paper: https://github.com/griano/epistoch/blob/master/paper/epistoch/epi_stoch.pdf
